@@ -33,6 +33,20 @@ return [
 			'url' => '/not-found',
 			'verb' => 'GET',
 		],
+
+		[
+			'name' => 'Page#showCall',
+			'url' => '/call/{token}',
+			'verb' => 'GET',
+			'root' => '',
+		],
+		[
+			'name' => 'Page#authenticatePassword',
+			'url' => '/call/{token}',
+			'verb' => 'POST',
+			'root' => '',
+		],
+
 	],
 	'ocs' => [
 		/**
@@ -46,6 +60,15 @@ return [
 				'apiVersion' => 'v1',
 			],
 		],
+		[
+			'name' => 'Signaling#getWelcomeMessage',
+			'url' => '/api/{apiVersion}/signaling/welcome/{serverId}',
+			'verb' => 'GET',
+			'requirements' => [
+				'apiVersion' => 'v1',
+				'serverId' => '^\d+$',
+			],
+		],
 		[
 			'name' => 'Signaling#backend',
 			'url' => '/api/{apiVersion}/signaling/backend',
@@ -151,20 +174,24 @@ return [
 			'name' => 'Room#getRooms',
 			'url' => '/api/{apiVersion}/room',
 			'verb' => 'GET',
-			'requirements' => ['apiVersion' => 'v1'],
+			'requirements' => [
+				'apiVersion' => 'v(1|2)',
+			],
 		],
 		[
 			'name' => 'Room#createRoom',
 			'url' => '/api/{apiVersion}/room',
 			'verb' => 'POST',
-			'requirements' => ['apiVersion' => 'v1'],
+			'requirements' => [
+				'apiVersion' => 'v(1|2)',
+			],
 		],
 		[
 			'name' => 'Room#getSingleRoom',
 			'url' => '/api/{apiVersion}/room/{token}',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -173,7 +200,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -182,7 +209,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -191,7 +218,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/public',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -200,7 +227,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/public',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -209,7 +236,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/read-only',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -218,7 +245,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/password',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -227,7 +254,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -236,7 +263,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -245,7 +272,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -254,7 +281,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/self',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -263,7 +290,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/guests',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -272,7 +299,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/active',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -281,7 +308,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/active',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -290,7 +317,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/moderators',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -299,7 +326,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/moderators',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -308,7 +335,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/favorite',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -317,7 +344,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/favorite',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -326,7 +353,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/notify',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -397,11 +424,22 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/{webinar}/lobby',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v1',
+				'apiVersion' => 'v(1|2)',
 				'webinar' => 'webinary?',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+
+		/**
+		 * UserSettings
+		 */
+		[
+			'name' => 'Settings#setUserSetting',
+			'url' => '/api/{apiVersion}/settings/user',
+			'verb' => 'POST',
+			'requirements' => [
+				'apiVersion' => 'v1',
+			],
+		],
 	],
 ];
-
