@@ -2,6 +2,7 @@ OC.L10N.register(
     "spreed",
     {
     "Guest" : "ضيف",
+    "You created the conversation" : "أنشأتَ المحادثة",
     "You left the call" : "لقد قمت بمغادرة المكالمة",
     "Click the button below to join." : "اضغط على الزر للانضمام.",
     "Conversation not found" : "المحادثة غير موجودة",
@@ -22,12 +23,13 @@ OC.L10N.register(
     "Copy link" : "انسخ الرابط",
     "Mute audio" : "كتم الصوت",
     "Disable video" : "تعطيل الفيديو",
+    "You" : "أنت",
+    "Drop your files to upload" : "افلت الملفات لرفعها",
     "Favorite" : "المفضلة",
     "Leave conversation" : "غادر المحادثة",
     "Delete conversation" : "احذف المحادثة",
     "Remove from favorites" : "إزالتها مِن المفضلة",
     "Add to favorites" : "أضفه إلى المفضلة",
-    "Contacts" : "المُراسِلون",
     "Loading" : "Loading",
     "Groups" : "الفِرَق",
     "Error" : "خطأ",
@@ -40,6 +42,7 @@ OC.L10N.register(
     "Yesterday" : "البارحة",
     "Send message" : "أرسل رسالة",
     "No results" : "دون أية نتيجة",
+    "Add users or groups" : "Add users or groups",
     "Participants" : "المشاركون",
     "Chat" : "الدردشة",
     "Projects" : "المشاريع",
@@ -67,11 +70,11 @@ OC.L10N.register(
     "Change password" : "تعديل الكلمة السرية",
     "Set password" : "تعيين كلمة سرية",
     "Rename" : "إعادة التسمية",
-    "You" : "أنت",
     "Send" : "أرسل",
     "Share" : "شارك",
     "Error while sharing" : "حصل خطأ عند عملية المشاركة",
     "Favorited" : "المفضلة",
-    "Join conversations at any time, any where, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز"
+    "Join conversations at any time, any where, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
+    "Contacts" : "المُراسِلون"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
