@@ -29,10 +29,10 @@ OC.L10N.register(
     "Mute audio" : "Спиране на звука",
     "Disable video" : "Изключване на видеото",
     "Enable video" : "Включи видео",
+    "You" : "Ти",
     "Favorite" : "Любима",
     "Remove from favorites" : "Премахни от любимите",
     "Add to favorites" : "Добави към любимите",
-    "Contacts" : "Контакти",
     "Loading" : "Зареждане",
     "Groups" : "Групи",
     "Circles" : "Обкръжения",
@@ -49,6 +49,7 @@ OC.L10N.register(
     "Remove participant" : "Премахване на участник",
     "Searching …" : "Търсене ...",
     "No results" : "Няма резултати",
+    "Add users or groups" : "Add users or groups",
     "Participants" : "Участници",
     "Chat" : "Съобщения",
     "Settings" : "Настройки",
@@ -82,11 +83,11 @@ OC.L10N.register(
     "Set password" : "Задайте парола",
     "Rename" : "Преименуване",
     "Link copied!" : "Връзката е копирана!",
-    "You" : "Ти",
     "Send" : "Изпрати",
     "Share" : "Споделяне",
     "Error while sharing" : "Грешка при споделяне",
     "Share screen" : "Споделяне на екран",
-    "Favorited" : "Отбелязано в любими"
+    "Favorited" : "Отбелязано в любими",
+    "Contacts" : "Контакти"
 },
 "nplurals=2; plural=(n != 1);");
