@@ -12,7 +12,6 @@ OC.L10N.register(
     "Favorite" : "প্রিয়জন",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Contacts" : "পরিচিতজন",
     "Loading" : "Loading",
     "Groups" : "গোষ্ঠীসমূহ",
     "Error" : "সমস্যা",
@@ -23,6 +22,7 @@ OC.L10N.register(
     "Today" : "আজ",
     "Yesterday" : "গতকাল",
     "guest" : "অতিথি",
+    "Add users or groups" : "Add users or groups",
     "Settings" : "সেটিংস",
     "Edit" : "সম্পাদনা",
     "Share link" : "লিংক ভাগাভাগি করেন",
@@ -35,6 +35,7 @@ OC.L10N.register(
     "Rename" : "পূনঃনামকরণ",
     "Send" : "পাঠাও",
     "Share" : "ভাগাভাগি কর",
-    "Error while sharing" : "ভাগাভাগি করতে সমস্যা দেখা দিয়েছে  "
+    "Error while sharing" : "ভাগাভাগি করতে সমস্যা দেখা দিয়েছে  ",
+    "Contacts" : "পরিচিতজন"
 },
 "nplurals=2; plural=(n != 1);");
