@@ -222,7 +222,7 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
     "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
     "You have been muted by a moderator" : "Du er blevet sat på mute af en moderator",
-    "Your screen" : "Din skærm",
+    "You" : "Dig",
     "Show screen" : "Vis skærm",
     "Mute" : "Mute",
     "You need to be logged in to upload files" : "Du skal være logget ind for at kunne uploade filer",
@@ -241,15 +241,11 @@ OC.L10N.register(
     "You need to promote a new moderator before you can leave the conversation." : "Du skal udnævne en ny moderator før du kan forlade samtalen.",
     "No matches" : "Ingen matches",
     "Conversations" : "Samtaler",
-    "Contacts" : "Kontakter",
     "Loading" : "Indlæser",
     "No search results" : "Ingen søgeresultater",
     "Groups" : "Grupper",
     "Circles" : "Cirkler",
     "Default location for attachments" : "Standard-lokation for vedhæftninger",
-    "Contacts, groups and circles" : "Kontakter, grupper og cirkler",
-    "Contacts and groups" : "Kontakter og grupper",
-    "Contacts and circles" : "Kontakter og cirkler",
     "Groups and circles" : "Grupper og cirkler",
     "Other sources" : "Andre kilder",
     "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger",
@@ -272,7 +268,6 @@ OC.L10N.register(
     "An error occurred while performing the search" : "Der opstod en fejl under søgningen",
     "Conversation name" : "Samtalenavn",
     "Allow guests to join via link " : "Tillad gæster at deltage via link",
-    "Search conversations or contacts" : "Søg efter samtaler og kontakter",
     "You are currently waiting in the lobby" : "Du venter nu i lobbyen",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du venter nu i lobbyen. Dette møde er planlagt til {startTime}",
     "Reply" : "Besvar",
@@ -290,16 +285,12 @@ OC.L10N.register(
     "Demote from moderator" : "Degrader fra moderator",
     "Promote to moderator" : "Forfrem til moderator",
     "Remove participant" : "Fjern deltager",
-    "Add contacts" : "Tilføj kontakter",
     "Add groups" : "Tilføj grupper",
     "Add emails" : "Tilføj emails",
     "Add circles" : "Tilføj cirkler",
     "Searching …" : "Søger ...",
     "No results" : "Ingen resultater",
-    "Search for more contacts" : "Søg efter flere kontakter",
-    "Add contacts, groups or circles" : "Tilføj kontakter, grupper eller cirkler",
-    "Add contacts or groups" : "Tilføj kontakter eller grupper",
-    "Add contacts or circles" : "Tilføj kontakter eller cirkler",
+    "Add users or groups" : "Add users or groups",
     "Add groups or circles" : "Tilføj grupper eller cirkler",
     "Add other sources" : "Tilføj andre kilder",
     "Add participants to the conversation" : "Tilføj deltagere til samtalen",
@@ -385,7 +376,6 @@ OC.L10N.register(
     "Error occurred while changing lobby state" : "Kunne ikke ændre lobby-tilstanden",
     "Invalid start time format" : "Ugyldigt format for starttid",
     "Error occurred while setting the lobby start time" : "Kunne ikke sætte lobby-starttiden",
-    "You" : "Dig",
     "No messages yet, start the conversation!" : "Ingen beskeder endnu, start samtalen!",
     "New message …" : "Ny besked …",
     "Send" : "Send",
@@ -410,6 +400,7 @@ OC.L10N.register(
     "Error while removing user from room" : "Fejl under fjernelse af bruger fra rummet",
     "Add participant …" : "Tilføj deltager…",
     "Favorited" : "Tilføjet til favoritter",
+    "Your screen" : "Din skærm",
     "{participantName}'s screen" : "{participantName}s skærm",
     "Guest's screen" : "Gæsts skærm",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Samtaler kan nu have en lobby. Dette giver mulighed for at moderatorer kan forbinde til samtalen for at forberede mødet, mens almindelige brugere og gæster må vente",
@@ -421,8 +412,18 @@ OC.L10N.register(
     "Who can start a call?" : "Hvem kan starte et opkald?",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-server bruges som proxy for trafik fra deltagere som er bag en firewall.",
     "Join conversations at any time, any where, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
+    "Contacts" : "Kontakter",
+    "Contacts, groups and circles" : "Kontakter, grupper og cirkler",
+    "Contacts and groups" : "Kontakter og grupper",
+    "Contacts and circles" : "Kontakter og cirkler",
     "Loading contacts" : "Henter kontakter",
     "Select participants" : "Vælg deltagere",
-    "Contacts loading" : "Henter kontakter"
+    "Search conversations or contacts" : "Søg efter samtaler og kontakter",
+    "Search for more contacts" : "Søg efter flere kontakter",
+    "Contacts loading" : "Henter kontakter",
+    "Add contacts" : "Tilføj kontakter",
+    "Add contacts, groups or circles" : "Tilføj kontakter, grupper eller cirkler",
+    "Add contacts or groups" : "Tilføj kontakter eller grupper",
+    "Add contacts or circles" : "Tilføj kontakter eller cirkler"
 },
 "nplurals=2; plural=(n != 1);");
