@@ -66,7 +66,7 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Screensharing extension is required to share your screen.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Please use a different browser like Firefox or Chrome to share your screen.",
     "An error occurred while starting screensharing." : "An error occurred while starting screensharing.",
-    "Your screen" : "Your screen",
+    "You" : "You",
     "Show screen" : "Show screen",
     "Favorite" : "Favourite",
     "Leave conversation" : "Leave conversation",
@@ -74,7 +74,6 @@ OC.L10N.register(
     "Remove from favorites" : "Remove from favourites",
     "Add to favorites" : "Add to favourites",
     "Conversations" : "Conversations",
-    "Contacts" : "Contacts",
     "Loading" : "Loading",
     "Groups" : "Groups",
     "Circles" : "Circles",
@@ -94,6 +93,7 @@ OC.L10N.register(
     "Promote to moderator" : "Promote to moderator",
     "Remove participant" : "Remove participant",
     "No results" : "No results",
+    "Add users or groups" : "Add users or groups",
     "Participants" : "Participants",
     "Chat" : "Chat",
     "Settings" : "Settings",
@@ -138,7 +138,6 @@ OC.L10N.register(
     "Link copied!" : "Link copied!",
     "Conversation with {name}" : "Conversation with {name}",
     "Error occurred while setting password" : "Error occurred while setting password",
-    "You" : "You",
     "No messages yet, start the conversation!" : "No messages yet, start the conversation!",
     "New message …" : "New message …",
     "Send" : "Send",
@@ -156,9 +155,11 @@ OC.L10N.register(
     "Screensharing is not supported by your browser." : "Screensharing is not supported by your browser.",
     "Add participant …" : "Add participant …",
     "Favorited" : "Favourited",
+    "Your screen" : "Your screen",
     "{participantName}'s screen" : "{participantName}'s screen",
     "Guest's screen" : "Guest's screen",
     "Limit app usage to groups." : "Limit app usage to groups.",
-    "Join conversations at any time, any where, on any device." : "Join conversations at any time, any where, on any device."
+    "Join conversations at any time, any where, on any device." : "Join conversations at any time, any where, on any device.",
+    "Contacts" : "Contacts"
 },
 "nplurals=2; plural=(n != 1);");
