@@ -32,13 +32,12 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
-    "Your screen" : "Su pantalla",
+    "You" : "Usted",
     "Favorite" : "Favorito",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Eliminar conversación",
     "Remove from favorites" : "Eliminado de favoritos",
     "Add to favorites" : "Agregar a favoritos",
-    "Contacts" : "Contactos",
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
@@ -51,7 +50,9 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "Send message" : "Enviar mensaje",
+    "Searching …" : "Buscando ...",
     "No results" : "Sin resultados",
+    "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
     "Settings" : "Ajustes",
@@ -85,7 +86,6 @@ OC.L10N.register(
     "Change password" : "Cambiar contraseña",
     "Set password" : "Configurar contraseña",
     "Rename" : "Renombrar",
-    "You" : "Usted",
     "Send" : "Enviar",
     "Share" : "Compartir",
     "Error while sharing" : "Se presentó un error al compartir",
@@ -97,7 +97,9 @@ OC.L10N.register(
     "Share screen" : "Compartir la pantalla",
     "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por su navegador. ",
     "Favorited" : "Marcado como favorito",
+    "Your screen" : "Su pantalla",
     "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado"
+    "Guest's screen" : "Pantalla del invitado",
+    "Contacts" : "Contactos"
 },
 "nplurals=2; plural=(n != 1);");
