@@ -139,7 +139,7 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
-    "Your screen" : "Tu pantalla",
+    "You" : "Tú",
     "Show screen" : "Mostrar pantalla",
     "Favorite" : "Hacer favorito",
     "Leave conversation" : "Dejar la conversación",
@@ -147,7 +147,6 @@ OC.L10N.register(
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Conversations" : "Conversaciones",
-    "Contacts" : "Contactos",
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
@@ -166,6 +165,7 @@ OC.L10N.register(
     "Promote to moderator" : "Promover a moderador",
     "Remove participant" : "Eliminar participante",
     "No results" : "Sin resultados",
+    "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
     "Settings" : "Configuraciones ",
@@ -210,7 +210,6 @@ OC.L10N.register(
     "Link copied!" : "¡Liga copiada!",
     "Conversation with {name}" : "Conversación con {name}",
     "Error occurred while setting password" : "Se presentó un error al establecer al contraseña",
-    "You" : "Tú",
     "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
     "New message …" : "Mensaje nuevo ...",
     "Send" : "Enviar",
@@ -228,9 +227,11 @@ OC.L10N.register(
     "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
     "Add participant …" : "Agregar participante ...",
     "Favorited" : "Marcado como favorito",
+    "Your screen" : "Tu pantalla",
     "{participantName}'s screen" : "Pantalla de {participantName}",
     "Guest's screen" : "Pantalla del invitado",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Las conversaciones ahora pueden tener un lobby. Esto permitirá a moderadores preparar el char y llamadas para jutas, mientras usuarios e invitados esperan.",
-    "Join conversations at any time, any where, on any device." : "Únete a conversaciones en cualquier momento, en cualquier lugar, en cualquier dispositivo."
+    "Join conversations at any time, any where, on any device." : "Únete a conversaciones en cualquier momento, en cualquier lugar, en cualquier dispositivo.",
+    "Contacts" : "Contactos"
 },
 "nplurals=2; plural=(n != 1);");
