@@ -83,6 +83,7 @@ OC.L10N.register(
     "File is not shared, or shared but not with the user" : "پرونده به اشتراک گذاشته نمی شود ، یا به اشتراک گذاشته اما با کاربر به اشتراک گذاشته نمی شود",
     "Write to conversation" : "برای مکالمه بنویسید",
     "Writes event information into a conversation of your choice" : "اطلاعات رویداد را در گفتگوی مورد نظر شما می نویسد",
+    "Private conversation" : "مکالمه خصوصی",
     "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر است ، قالب تاریخ باید YYYY-MM-DD باشد",
     "Limit to groups" : "محدود کردن به گروه ها",
     "Everyone" : "همه",
@@ -97,12 +98,13 @@ OC.L10N.register(
     "Off" : "خاموش",
     "Saved" : "ذخیره شد",
     "Copy link" : "کپی کردن لینک",
+    "You" : "شما",
+    "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
     "Favorite" : "برگزیده",
     "Leave conversation" : "ترک صحبت",
     "Delete conversation" : "مکالمه را حذف کنید",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Contacts" : "مخاطبین",
     "Loading" : "در حال بار گزاری",
     "Groups" : "گروه ها",
     "Circles" : "حلقه ها",
@@ -121,6 +123,7 @@ OC.L10N.register(
     "Remove participant" : "شرکت کننده را حذف کنید",
     "Searching …" : "جستجوکردن …",
     "No results" : "نتیجه ای یافت نشد",
+    "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
     "Participants" : "شركت كنندگان",
     "Projects" : "پروژه ها",
     "Settings" : "تنظیمات",
@@ -148,11 +151,11 @@ OC.L10N.register(
     "Change password" : "تغییر گذر واژه",
     "Set password" : "قراردادن رمز عبور",
     "Rename" : "تغییرنام",
-    "You" : "شما",
     "Send" : "ارسال",
     "Share" : "هم‌رسانی",
     "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
     "Favorited" : "برگزیده شده",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- مکالمات اکنون می توانند یک لابی داشته باشند. این به مدیران اجازه می دهد تا برای تهیه جلسه به چت بپیوندند و از قبل تماس بگیرند ، در حالی که کاربران و میهمانان باید منتظر بمانند."
+    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- مکالمات اکنون می توانند یک لابی داشته باشند. این به مدیران اجازه می دهد تا برای تهیه جلسه به چت بپیوندند و از قبل تماس بگیرند ، در حالی که کاربران و میهمانان باید منتظر بمانند.",
+    "Contacts" : "مخاطبین"
 },
 "nplurals=2; plural=(n > 1);");
