@@ -171,7 +171,7 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
     "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
-    "Your screen" : "Sinun näyttösi",
+    "You" : "Sinä",
     "Show screen" : "Näytä näyttö",
     "Mute" : "Mykistä",
     "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
@@ -186,14 +186,10 @@ OC.L10N.register(
     "You: {lastMessage}" : "Sinä: {lastMessage}",
     "No matches" : "Ei täsmääviä",
     "Conversations" : "Keskustelut",
-    "Contacts" : "Yhteystiedot",
     "Loading" : "Ladataan",
     "No search results" : "Ei hakutuloksia",
     "Groups" : "Ryhmät",
     "Circles" : "Piirit",
-    "Contacts, groups and circles" : "Yhteystiedot, ryhmät ja piirit",
-    "Contacts and groups" : "Yhteystiedot ja ryhmät",
-    "Contacts and circles" : "Yhteystiedot ja piirit",
     "Groups and circles" : "Ryhmät ja piirit",
     "Other sources" : "Muut lähteet",
     "Select default location for attachments" : "Valitse liitteiden oletussijainti",
@@ -215,7 +211,6 @@ OC.L10N.register(
     "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
     "Conversation name" : "Keskustelun nimi",
     "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
-    "Search conversations or contacts" : "Hae keskusteluja tai yhteystietoja",
     "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
     "Reply" : "Vastaa",
@@ -230,15 +225,12 @@ OC.L10N.register(
     "Demote from moderator" : "Alenna moderaattorista",
     "Promote to moderator" : "Ylennä moderaattoriksi",
     "Remove participant" : "Poista osallistuja",
-    "Add contacts" : "Lisää yhteystietoja",
     "Add groups" : "Lisää ryhmiä",
     "Add emails" : "Lisää sähköpostiosoitteita",
     "Add circles" : "Lisää piirejä",
     "Searching …" : "Haetaan…",
     "No results" : "Ei tuloksia",
-    "Add contacts, groups or circles" : "Lisää yhteystietoja, ryhmiä tai piirejä",
-    "Add contacts or groups" : "Lisää yhteystietoja tai ryhmiä",
-    "Add contacts or circles" : "Lisää yhteystietoja tai piirejä",
+    "Add users or groups" : "Lisää käyttäjiä tai ryhmiä",
     "Add groups or circles" : "Lisää ryhmiä tai piirejä",
     "Add other sources" : "Lisää muita lähteitä",
     "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
@@ -314,7 +306,6 @@ OC.L10N.register(
     "Error occurred while making the conversation private" : "Keskustelua tehtäessä yksityiseksi tapahtui virhe",
     "Error occurred while setting password" : "Virhe salasanaa asettaessa",
     "Invalid start time format" : "Virheellinen aloitusajan muoto",
-    "You" : "Sinä",
     "No messages yet, start the conversation!" : "Ei vielä viestejä, aloita keskustelu!",
     "New message …" : "Uusi viesti …",
     "Send" : "Lähetä",
@@ -337,13 +328,23 @@ OC.L10N.register(
     "Error while removing user from room" : "Virhe poistaessa käyttäjää huoneesta",
     "Add participant …" : "Lisää osallistuja…",
     "Favorited" : "Lisätty suosikkeihin",
+    "Your screen" : "Sinun näyttösi",
     "{participantName}'s screen" : "Henkilön {participantName} näyttö",
     "Guest's screen" : "Vieraan näyttö",
     "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
     "Who can start a call?" : "Kuka voi aloittaa puhelun?",
     "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
+    "Contacts" : "Yhteystiedot",
+    "Contacts, groups and circles" : "Yhteystiedot, ryhmät ja piirit",
+    "Contacts and groups" : "Yhteystiedot ja ryhmät",
+    "Contacts and circles" : "Yhteystiedot ja piirit",
     "Loading contacts" : "Ladataan yhteystietoja",
     "Select participants" : "Valitse osallistujat",
-    "Contacts loading" : "Yhteystiedot latautuvat"
+    "Search conversations or contacts" : "Hae keskusteluja tai yhteystietoja",
+    "Contacts loading" : "Yhteystiedot latautuvat",
+    "Add contacts" : "Lisää yhteystietoja",
+    "Add contacts, groups or circles" : "Lisää yhteystietoja, ryhmiä tai piirejä",
+    "Add contacts or groups" : "Lisää yhteystietoja tai ryhmiä",
+    "Add contacts or circles" : "Lisää yhteystietoja tai piirejä"
 },
 "nplurals=2; plural=(n != 1);");
