@@ -127,7 +127,7 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
     "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
-    "Your screen" : "המסך שלך",
+    "You" : "אני",
     "Show screen" : "הצגת מסך",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Favorite" : "סימון כמועדף",
@@ -138,12 +138,9 @@ OC.L10N.register(
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
     "Conversations" : "דיונים",
-    "Contacts" : "אנשי קשר",
     "Loading" : "בטעינה",
     "Groups" : "קבוצות",
     "Circles" : "מעגלים",
-    "Contacts and groups" : "אנשי קשר וקבוצות",
-    "Contacts and circles" : "אנשי קשר ומעגלים",
     "Groups and circles" : "קבוצות ומעגלים",
     "Other sources" : "מקורות אחרים",
     "Invalid path selected" : "הנתיב שנבחר שגוי",
@@ -164,7 +161,6 @@ OC.L10N.register(
     "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
     "Conversation name" : "שם דיון",
     "Allow guests to join via link " : "לאפשר לאורחים להצטרף דרך קישור",
-    "Search conversations or contacts" : "חיפוש דיונים או אנשי קשר",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "בנך בהמתנה בלובי. פגישה זו זומנה ל־{startTime}",
     "Reply" : "תגובה",
@@ -183,16 +179,12 @@ OC.L10N.register(
     "Demote from moderator" : "הורדה מדרגת פיקוח",
     "Promote to moderator" : "קידום לדרגת פיקוח",
     "Remove participant" : "הסרת משתתף",
-    "Add contacts" : "הוספת אנשי קשר",
     "Add groups" : "הוספת קבוצות",
     "Add emails" : "הוספת כתובות דוא״ל",
     "Add circles" : "הוספת מעגלים",
     "Searching …" : "מתבצע חיפוש…",
     "No results" : "אין תוצאות",
-    "Search for more contacts" : "חיפוש אחר אנשי קשר נוספים",
-    "Add contacts, groups or circles" : "הוספת אנשי קשר, קבוצות או מעגלים",
-    "Add contacts or groups" : "הוספת אנשי קשר או קבוצות",
-    "Add contacts or circles" : "הוספת אנשי קשר או מעגלים",
+    "Add users or groups" : "Add users or groups",
     "Add groups or circles" : "הוספת קבוצות או מעגלים",
     "Add other sources" : "הוספת מקורות אחרים",
     "Add participants to the conversation" : "הוספת משתתפים לדיון",
@@ -255,7 +247,6 @@ OC.L10N.register(
     "Link copied!" : "קישור הועתק!",
     "Conversation with {name}" : "דיון עם {name}",
     "Error occurred while setting password" : "אירעה שגיאה בעת הגדרת ססמה",
-    "You" : "אני",
     "No messages yet, start the conversation!" : "אין הודעות עדיין, ניתן להתחיל בדיון!",
     "New message …" : "הודעה חדשה…",
     "Send" : "שליחה",
@@ -274,9 +265,19 @@ OC.L10N.register(
     "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
     "Add participant …" : "הוספת משתתף…",
     "Favorited" : "סומן כמועדף",
+    "Your screen" : "המסך שלך",
     "{participantName}'s screen" : "המסך של {participantName}",
     "Guest's screen" : "המסך של האורח/ת",
     "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
-    "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר."
+    "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר.",
+    "Contacts" : "אנשי קשר",
+    "Contacts and groups" : "אנשי קשר וקבוצות",
+    "Contacts and circles" : "אנשי קשר ומעגלים",
+    "Search conversations or contacts" : "חיפוש דיונים או אנשי קשר",
+    "Search for more contacts" : "חיפוש אחר אנשי קשר נוספים",
+    "Add contacts" : "הוספת אנשי קשר",
+    "Add contacts, groups or circles" : "הוספת אנשי קשר, קבוצות או מעגלים",
+    "Add contacts or groups" : "הוספת אנשי קשר או קבוצות",
+    "Add contacts or circles" : "הוספת אנשי קשר או מעגלים"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
