@@ -5,6 +5,7 @@ OC.L10N.register(
     "Limit to groups" : "Batasi ke grup",
     "Everyone" : "Semua orang",
     "Save changes" : "Simpan perubahan",
+    "Saving …" : "Menyimpan ...",
     "None" : "Tidak ada",
     "User" : "Pengguna",
     "Disabled" : "Dinonaktifkan",
@@ -12,12 +13,13 @@ OC.L10N.register(
     "Name" : "Nama",
     "Saved" : "Disimpan",
     "Copy link" : "Salin tautan",
+    "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
     "Favorite" : "Favorit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
-    "Contacts" : "Kontak",
     "Loading" : "Memuat",
     "Groups" : "Grup",
+    "Invalid path selected" : "Jalur terpilih invalid",
     "Error" : "Kesalahan",
     "Password protect" : "Lindungi dengan kata sandi",
     "Back" : "Kembali",
@@ -27,6 +29,7 @@ OC.L10N.register(
     "Yesterday" : "Kemarin",
     "guest" : "pengunjung",
     "No results" : "Tidak ada hasil",
+    "Add users or groups" : "Add users or groups",
     "Settings" : "Setelan",
     "Edit" : "Sunting",
     "Dismiss" : "Batal",
@@ -51,6 +54,7 @@ OC.L10N.register(
     "Send" : "Kirim",
     "Share" : "Bagikan",
     "Error while sharing" : "Kesalahan saat membagikan",
-    "Favorited" : "Difavoritkan"
+    "Favorited" : "Difavoritkan",
+    "Contacts" : "Kontak"
 },
 "nplurals=1; plural=0;");
