@@ -171,7 +171,7 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
     "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
-    "Your screen" : "Skjárinn þinn",
+    "You" : "Þú",
     "Show screen" : "Birta skjá",
     "Favorite" : "Eftirlæti",
     "Leave conversation" : "Hætta í samtali",
@@ -180,7 +180,6 @@ OC.L10N.register(
     "Add to favorites" : "Bæta í eftirlæti",
     "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
     "Conversations" : "Samtöl",
-    "Contacts" : "Tengiliðir",
     "Loading" : "Hleð inn",
     "Groups" : "Hópar",
     "Circles" : "Hringir",
@@ -190,7 +189,6 @@ OC.L10N.register(
     "Back" : "Til baka",
     "Close" : "Loka",
     "Conversation name" : "Heiti samtals",
-    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum",
     "Reply" : "Svara",
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
@@ -204,6 +202,7 @@ OC.L10N.register(
     "Remove participant" : "Fjarlægja þátttakanda",
     "Searching …" : "Leita …",
     "No results" : "Engar niðurstöður",
+    "Add users or groups" : "Bæta við notendum eða hópum",
     "Participants" : "Þátttakendur",
     "Chat" : "Spjall",
     "Projects" : "Verkefni",
@@ -264,7 +263,6 @@ OC.L10N.register(
     "Link copied!" : "Tengill afritaður!",
     "Conversation with {name}" : "Samtal við {name}",
     "Error occurred while setting password" : "Villa kom upp við að stilla lykilorð",
-    "You" : "Þú",
     "No messages yet, start the conversation!" : "Engin skilaboð ennþá, byrjaðu umræðuna!",
     "New message …" : "Ný skilaboð …",
     "Send" : "Senda",
@@ -289,11 +287,14 @@ OC.L10N.register(
     "Error while removing user from room" : "Villa við að fjarlægja notanda úr spjallsvæði",
     "Add participant …" : "Bæta við þátttakanda…",
     "Favorited" : "Sett í eftirlæti",
+    "Your screen" : "Skjárinn þinn",
     "{participantName}'s screen" : "Skjár {participantName}",
     "Guest's screen" : "Skjár gests",
     "Limit app usage to groups." : "Takmarka notkun forrits við tiltekna hópa.",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Skipanir er nýr eiginleiki í Nextcloud Talk. Þær gera þér kleift að keyra skriftur á Nextcloud-þjóninum þínum. Þú getur skilgreint þær með skipanalínuviðmóti okkar. Þæmi um reiknivélarskriftu má finna í <a {attributes}>hjálparskjölunum ↗</a>.",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
-    "Join conversations at any time, any where, on any device." : "Taktu þátt í samtölum hvenær sem er, hvar sem er, á hvaða tæki sem er."
+    "Join conversations at any time, any where, on any device." : "Taktu þátt í samtölum hvenær sem er, hvar sem er, á hvaða tæki sem er.",
+    "Contacts" : "Tengiliðir",
+    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
