@@ -53,12 +53,11 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
     "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
-    "Your screen" : "თქვენი ეკრანი",
+    "You" : "თქვენ",
     "Show screen" : "ეკრანის ჩვენება",
     "Favorite" : "რჩეული",
     "Remove from favorites" : "რჩეულებიდან ამოშლა",
     "Add to favorites" : "რჩეულებში დამატება",
-    "Contacts" : "კონტაქტები",
     "Loading" : "იტვირთება",
     "Groups" : "ჯგუფები",
     "Circles" : "წრეები",
@@ -76,6 +75,7 @@ OC.L10N.register(
     "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
     "Remove participant" : "მონაწილის ამოშლა",
     "No results" : "შედეგები არაა",
+    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
     "Participants" : "მონაწილეები",
     "Chat" : "ჩეთი",
     "Settings" : "პარამეტრები",
@@ -113,7 +113,6 @@ OC.L10N.register(
     "Link copied!" : "ბმული დაკოპირდა!",
     "Conversation with {name}" : "საუბარი მომხმარებელთან {name}",
     "Error occurred while setting password" : "პაროლის დაყენებისას წარმოიქმნა შეცდომა",
-    "You" : "თქვენ",
     "No messages yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
     "Send" : "გაგზავნა",
     "Share" : "გაზიარება",
@@ -129,7 +128,9 @@ OC.L10N.register(
     "No Camera" : "კამერა არაა",
     "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
     "Favorited" : "დამატებულია რჩეულებში",
+    "Your screen" : "თქვენი ეკრანი",
     "{participantName}'s screen" : "{participantName} მომხმარებლის ეკრანი",
-    "Guest's screen" : "სტუმრის ეკრანი"
+    "Guest's screen" : "სტუმრის ეკრანი",
+    "Contacts" : "კონტაქტები"
 },
 "nplurals=2; plural=(n!=1);");
