@@ -35,8 +35,10 @@ OC.L10N.register(
     "Talk updates ✅" : "Pokalbių programėlės atnaujinimai ✅",
     "{actor} created the conversation" : "{actor} sukūrė pokalbį",
     "You created the conversation" : "Jūs sukūrėte pokalbį",
+    "An administrator created the conversation" : "Administratorius sukūrė pokalbį",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
+    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratorius pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
     "{actor} started a call" : "{actor} pradėjo skambutį",
     "You started a call" : "Jūs pradėjote skambutį",
     "{actor} joined the call" : "{actor} prisijungė prie skambučio",
@@ -45,8 +47,10 @@ OC.L10N.register(
     "You left the call" : "Jūs išėjote iš skambučio",
     "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
     "You unlocked the conversation" : "Jūs atrakinote pokalbį",
+    "An administrator unlocked the conversation" : "Administratorius atrakino pokalbį",
     "{actor} locked the conversation" : "{actor} užrakino pokalbį",
     "You locked the conversation" : "Jūs užrakinote pokalbį",
+    "An administrator locked the conversation" : "Administratorius užrakino pokalbį",
     "The conversation is now open to everyone" : "Dabar, pokalbis yra atviras visiems",
     "{actor} opened the conversation to everyone" : "{actor} atvėrė pokalbį visiems",
     "You opened the conversation to everyone" : "Jūs atvėrėte pokalbį visiems",
@@ -58,8 +62,10 @@ OC.L10N.register(
     "You disallowed guests" : "Jūs nebeleidžiate svečių",
     "{actor} set a password" : "{actor} nustatė slaptažodį",
     "You set a password" : "Jūs nustatėte slaptažodį",
+    "An administrator set a password" : "Administratorius nustatė slaptažodį",
     "{actor} removed the password" : "{actor} pašalino slaptažodį",
     "You removed the password" : "Jūs pašalinote slaptažodį",
+    "An administrator removed the password" : "Administratorius pašalino slaptažodį",
     "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
     "You joined the conversation" : "Jūs prisijungėte prie pokalbio",
     "{actor} joined the conversation" : "{actor} prisijungė prie pokalbio",
@@ -214,8 +220,9 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
     "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
-    "Your screen" : "Jūsų ekranas",
+    "You" : "Jūs",
     "Show screen" : "Rodyti ekraną",
+    "Mute" : "Nutildyti",
     "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
     "Favorite" : "Mėgstamas",
     "Conversation settings" : "Pokalbio nustatymai",
@@ -229,15 +236,11 @@ OC.L10N.register(
     "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
     "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
     "Conversations" : "Pokalbiai",
-    "Contacts" : "Adresatai",
     "Loading" : "Įkeliama",
     "No search results" : "Nėra paieškos rezultatų",
     "Groups" : "Grupės",
     "Circles" : "Ratai",
     "Default location for attachments" : "Numatytoji priedų vieta",
-    "Contacts, groups and circles" : "Adresatai, grupės ir ratai",
-    "Contacts and groups" : "Adresatai ir grupės",
-    "Contacts and circles" : "Adresatai ir ratai",
     "Groups and circles" : "Grupės ir ratai",
     "Other sources" : "Kiti šaltiniai",
     "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams",
@@ -259,7 +262,6 @@ OC.L10N.register(
     "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
     "Conversation name" : "Pokalbio pavadinimas",
     "Allow guests to join via link " : "Leisti svečiams prisijungti per nuorodą",
-    "Search conversations or contacts" : "Ieškoti pokalbių ar adresatų",
     "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
     "Reply" : "Atsakyti",
@@ -277,16 +279,12 @@ OC.L10N.register(
     "Demote from moderator" : "Pažeminti iš moderatorių",
     "Promote to moderator" : "Paaukštinti į moderatorius",
     "Remove participant" : "Šalinti dalyvį",
-    "Add contacts" : "Pridėti adresatus",
     "Add groups" : "Pridėti grupes",
     "Add emails" : "Pridėti el. paštus",
     "Add circles" : "Pridėti ratus",
     "Searching …" : "Ieškoma…",
     "No results" : "Rezultatų nėra",
-    "Search for more contacts" : "Ieškoti daugiau adresatų",
-    "Add contacts, groups or circles" : "Pridėti adresatus, grupes ar ratus",
-    "Add contacts or groups" : "Pridėti adresatus ar grupes",
-    "Add contacts or circles" : "Pridėti adresatus ar ratus",
+    "Add users or groups" : "Pridėti naudotojus ar grupes",
     "Add groups or circles" : "Pridėti grupes ar ratus",
     "Add other sources" : "Pridėti kitus šaltinius",
     "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
@@ -318,8 +316,8 @@ OC.L10N.register(
     "Join a conversation or start a new one" : "Prisijunkite prie pokalbio arba pradėkite naują",
     "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai pilnai nepalaiko jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
     "Error while sharing file" : "Klaida bendrinant failą",
     "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės.",
     "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
@@ -370,7 +368,6 @@ OC.L10N.register(
     "Error occurred while changing lobby state" : "Klaida keičiant laukimo salės būseną",
     "Invalid start time format" : "Neteisingas pradžios laiko formatas",
     "Error occurred while setting the lobby start time" : "Klaida nustatant laukimo salės pradžios laiką",
-    "You" : "Jūs",
     "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
     "New message …" : "Nauja žinutė…",
     "Send" : "Siųsti",
@@ -395,6 +392,7 @@ OC.L10N.register(
     "Error while removing user from room" : "Klaida šalinant naudotoją iš kambario",
     "Add participant …" : "Pridėti dalyvį…",
     "Favorited" : "Pažymėtas mėgstamu",
+    "Your screen" : "Jūsų ekranas",
     "{participantName}'s screen" : "Dalyvio {participantName} ekranas",
     "Guest's screen" : "Svečio ekranas",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti.",
@@ -403,7 +401,17 @@ OC.L10N.register(
     "Start calls" : "Pradeda skambučius",
     "Who can start a call?" : "Kas gali pradėti skambutį?",
     "Join conversations at any time, any where, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
+    "Contacts" : "Adresatai",
+    "Contacts, groups and circles" : "Adresatai, grupės ir ratai",
+    "Contacts and groups" : "Adresatai ir grupės",
+    "Contacts and circles" : "Adresatai ir ratai",
     "Loading contacts" : "Įkeliami adresatai",
-    "Contacts loading" : "Įkeliami adresatai"
+    "Search conversations or contacts" : "Ieškoti pokalbių ar adresatų",
+    "Search for more contacts" : "Ieškoti daugiau adresatų",
+    "Contacts loading" : "Įkeliami adresatai",
+    "Add contacts" : "Pridėti adresatus",
+    "Add contacts, groups or circles" : "Pridėti adresatus, grupes ar ratus",
+    "Add contacts or groups" : "Pridėti adresatus ar grupes",
+    "Add contacts or circles" : "Pridėti adresatus ar ratus"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
