@@ -155,7 +155,7 @@ OC.L10N.register(
     "Enable screensharing" : "Овозможи споделување на екранот",
     "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
-    "Your screen" : "Вашиот екран",
+    "You" : "Вие",
     "Show screen" : "Прикажи екран",
     "Mute" : "Занеми",
     "Call in progress" : "Повик е во тек",
@@ -171,15 +171,11 @@ OC.L10N.register(
     "You need to promote a new moderator before you can leave the conversation." : "Треба да промовирате нов модератор пред да го напуштите разговорот.",
     "No matches" : "Нема совпаѓања",
     "Conversations" : "Разговори",
-    "Contacts" : "Контакти",
     "Loading" : "Се вчитува",
     "No search results" : "Нема резултати од пребарувањето",
     "Groups" : "Групи",
     "Circles" : "Кругови",
     "Default location for attachments" : "Стандардна локација за прилози",
-    "Contacts, groups and circles" : "Контакти, групи и кругови",
-    "Contacts and groups" : "Контакти и групи",
-    "Contacts and circles" : "Контакти и кругови",
     "Groups and circles" : "Групи и кругови",
     "Other sources" : "Други извори",
     "Select default location for attachments" : "Избери стандардна локација за прилози",
@@ -198,7 +194,6 @@ OC.L10N.register(
     "Search participants" : "Барај учесници",
     "Conversation name" : "Име на разговорот",
     "Allow guests to join via link " : "Дозволи им на гостите да се приклучат преку линк",
-    "Search conversations or contacts" : "Пребарување на разговори или контакти",
     "You are currently waiting in the lobby" : "Моментално чекате во лобито",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Моментално чекате во лобито. Состанокот е закажан во {startTime}",
     "Reply" : "Одговор",
@@ -213,16 +208,12 @@ OC.L10N.register(
     "guest" : "гостин",
     "Promote to moderator" : "Промовирај во модератор",
     "Remove participant" : "Одстрани учесник",
-    "Add contacts" : "Додади контакти",
     "Add groups" : "Додади групи",
     "Add emails" : "Додади Е-пошти",
     "Add circles" : "Додади кругови",
     "Searching …" : "Пребарување ...",
     "No results" : "Нема резултати",
-    "Search for more contacts" : "Пребарување за повеќе контакти",
-    "Add contacts, groups or circles" : "Додади контакти, групи или кругови",
-    "Add contacts or groups" : "Додади контакти или групи",
-    "Add contacts or circles" : "Додади контакти или кругови",
+    "Add users or groups" : "Add users or groups",
     "Add groups or circles" : "Додади групи или кругови",
     "Add other sources" : "Додади други извори",
     "Add participants to the conversation" : "Додадете учесници кон разговорот",
@@ -281,7 +272,6 @@ OC.L10N.register(
     "Conversation with {name}" : "Разговор со {name}",
     "Error occurred while setting password" : "Настана грешка при обидот за поставување на лозинка",
     "Invalid start time format" : "Погрешен формат за време на почеток",
-    "You" : "Вие",
     "No messages yet, start the conversation!" : "Сеуште нема пораки, започнете разговор!",
     "New message …" : "Нова порака ...",
     "Send" : "Испрати",
@@ -301,12 +291,23 @@ OC.L10N.register(
     "No Camera" : "Нема камера",
     "Add participant …" : "Додади учесници ...",
     "Favorited" : "Омилени",
+    "Your screen" : "Вашиот екран",
     "{participantName}'s screen" : "Екранот на {participantName}",
     "Guest's screen" : "Екранот на гостинот",
     "Who can start a call?" : "Кој може да започне повик?",
     "Join conversations at any time, any where, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
+    "Contacts" : "Контакти",
+    "Contacts, groups and circles" : "Контакти, групи и кругови",
+    "Contacts and groups" : "Контакти и групи",
+    "Contacts and circles" : "Контакти и кругови",
     "Loading contacts" : "Вчитување на контакти",
     "Select participants" : "Избери учесници",
-    "Contacts loading" : "Вчитување на контакти"
+    "Search conversations or contacts" : "Пребарување на разговори или контакти",
+    "Search for more contacts" : "Пребарување за повеќе контакти",
+    "Contacts loading" : "Вчитување на контакти",
+    "Add contacts" : "Додади контакти",
+    "Add contacts, groups or circles" : "Додади контакти, групи или кругови",
+    "Add contacts or groups" : "Додади контакти или групи",
+    "Add contacts or circles" : "Додади контакти или кругови"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
