@@ -53,7 +53,7 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
     "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
-    "Your screen" : "O seu ecrã",
+    "You" : "Você",
     "Show screen" : "Mostrar ecrã",
     "Favorite" : "Favorito",
     "Leave conversation" : "Sair da conversação",
@@ -61,7 +61,6 @@ OC.L10N.register(
     "Remove from favorites" : "Remover de favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
     "Conversations" : "Conversações",
-    "Contacts" : "Contactos",
     "Loading" : "A carregar",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
@@ -81,13 +80,14 @@ OC.L10N.register(
     "Promote to moderator" : "Promover a moderador",
     "Remove participant" : "Remover participante",
     "No results" : "Sem resultados",
+    "Add users or groups" : "Add users or groups",
     "Participants" : "Participantes",
     "Chat" : "Conversa",
     "Settings" : "Definições",
     "Edit" : "Editar",
     "Dismiss" : "Dispensar",
     "Rename conversation" : "Renomear conversação",
-    "Share link" : "Partilhar ligação",
+    "Share link" : "Partilhar hiperligação",
     "Password protection" : "Protegido por palavra-passe",
     "Enter a password" : "Insira uma palavra-passe",
     "Grid view" : "Vista em grelha",
@@ -116,7 +116,6 @@ OC.L10N.register(
     "Link copied!" : "Ligação copiada!",
     "Conversation with {name}" : "Conversa com {name}",
     "Error occurred while setting password" : "Ocorreu um erro a definir a palavra-passe",
-    "You" : "Você",
     "No messages yet, start the conversation!" : "Ainda não tem mensagens, comece a conversa!",
     "New message …" : "Nova mensagem...",
     "Send" : "Enviar",
@@ -132,8 +131,10 @@ OC.L10N.register(
     "No Camera" : "Sem Câmera",
     "Screensharing is not supported by your browser." : "O seu browser não suporta partilha de ecrã",
     "Favorited" : "Nos Favoritos",
+    "Your screen" : "O seu ecrã",
     "{participantName}'s screen" : "Ecrã de {participantName}",
     "Guest's screen" : "Ecrã do convidado",
-    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos."
+    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos.",
+    "Contacts" : "Contactos"
 },
 "nplurals=2; plural=(n != 1);");
