@@ -31,14 +31,13 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
     "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
-    "Your screen" : "Ekrani juaj",
+    "You" : "Ju",
     "Favorite" : "I/E Preferuar",
     "Leave conversation" : "Largohuni nga biseda",
     "Delete conversation" : "Fshijeni bisedën",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
     "Conversations" : "Bisedat",
-    "Contacts" : "Kontaktet",
     "Loading" : "Duke ngarkuar",
     "Groups" : "Grupet",
     "Circles" : "Rrethet",
@@ -53,6 +52,7 @@ OC.L10N.register(
     "Send message" : "Dërgo mesazh",
     "guest" : "vizitor",
     "No results" : "Asnjë rezultat",
+    "Add users or groups" : "Add users or groups",
     "Settings" : "Rregullimet",
     "Edit" : "Përpuno",
     "Dismiss" : "Hiq",
@@ -84,7 +84,6 @@ OC.L10N.register(
     "Change password" : "Ndryshoni fjalëkalimin",
     "Set password" : "Vendos fjalëkalimin",
     "Rename" : "Riemëroj",
-    "You" : "Ju",
     "Send" : "Dërgo",
     "Share" : "Shpërndaje",
     "Error while sharing" : "Gabim gjatë ndarjes",
@@ -96,7 +95,9 @@ OC.L10N.register(
     "Share screen" : "Ndaje ekranin",
     "Screensharing is not supported by your browser." : "Ndarja e erkaneve nuk është e mbështetur nga shfletuesi juaj ",
     "Favorited" : "U kalua e parapëlqyer",
+    "Your screen" : "Ekrani juaj",
     "{participantName}'s screen" : "Ekrani i {participantName}",
-    "Guest's screen" : "Ekrani i të ftuarit"
+    "Guest's screen" : "Ekrani i të ftuarit",
+    "Contacts" : "Kontaktet"
 },
 "nplurals=2; plural=(n != 1);");
