@@ -29,6 +29,7 @@ OC.L10N.register(
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svara direkt på meddelanden som ger de andra användarna mer sammanhang vad ditt meddelande handlar om",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Sökning efter konversationer och deltagare kommer nu också att filtrera dina befintliga konversationer, vilket gör det mycket lättare att hitta tidigare konversationer",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu lägga till anpassade användargrupper i konversationer när cirkelappen är installerad",
+    "New in Talk 9" : "Nytt i Talk 9",
     "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
     "The command does not exist" : "Kommandot finns inte",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Ett fel inträffade under körning av kommandot. Be en administratör att kontrollera loggarna.",
@@ -148,7 +149,7 @@ OC.L10N.register(
     "Limit creating conversations" : "Begränsa att skapa konversationer",
     "Limit starting a call" : "Begränsa att starta ett samtal",
     "Limit starting calls" : "Begränsa att starta samtal",
-    "When a call has started, everyone with access to the conversation can join the call." : "När ett samtal har startat kan alla som har tillgång till konversationen gå med i samtalet.",
+    "When a call has started, everyone with access to the conversation can join the call." : "När ett samtal har startat kan alla som har åtkomst till konversationen gå med i samtalet.",
     "Everyone" : "Alla",
     "Users and moderators" : "Användare och moderatorer",
     "Moderators only" : "Endast moderatorer",
@@ -237,9 +238,10 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
     "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
     "You have been muted by a moderator" : "Du har tystats av en moderator",
-    "Your screen" : "Din skärm",
+    "You" : "Du",
     "Show screen" : "Visa skärm",
     "Mute" : "Tyst",
+    "Stop following" : "Sluta följa",
     "You need to be logged in to upload files" : "Du måste vara inloggad för att ladda upp filer",
     "This conversation is read only" : "Denna konversation är skrivskyddad",
     "Drop your files to upload" : "Släpp dina filer för att ladda upp",
@@ -258,15 +260,14 @@ OC.L10N.register(
     "You need to promote a new moderator before you can leave the conversation." : "Du måste tilldela en ny moderator innan du kan lämna konversationen.",
     "No matches" : "Inga träffar",
     "Conversations" : "Konversationer",
-    "Contacts" : "Kontakter",
     "Loading" : "Läser in",
     "No search results" : "Inga sökresultat",
     "Groups" : "Grupper",
     "Circles" : "Cirklar",
     "Default location for attachments" : "Standardplats för bilagor",
-    "Contacts, groups and circles" : "Kontakter, grupper och cirklar",
-    "Contacts and groups" : "Kontakter och grupper",
-    "Contacts and circles" : "Kontakter och cirklar",
+    "Users, groups and circles" : "Användare, grupper och cirklar",
+    "Users and groups" : "Användare och grupper",
+    "Users and circles" : "Användare och cirklar",
     "Groups and circles" : "Grupper och cirklar",
     "Other sources" : "Andra källor",
     "Select default location for attachments" : "Välj standardplats för bilagor",
@@ -289,7 +290,7 @@ OC.L10N.register(
     "An error occurred while performing the search" : "Ett fel uppstod när sökningen utfördes",
     "Conversation name" : "Konversationens namn",
     "Allow guests to join via link " : "Tillåt gäster att ansluta via länk",
-    "Search conversations or contacts" : "Sök konversationer eller kontakter",
+    "Search conversations or users" : "Sök konversationer eller användare",
     "You are currently waiting in the lobby" : "Du väntar för närvarande i lobbyn",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
     "Reply" : "Svara",
@@ -309,16 +310,16 @@ OC.L10N.register(
     "Demote from moderator" : "Degradera från moderator",
     "Promote to moderator" : "Befordra till moderator",
     "Remove participant" : "Ta bort deltagare",
-    "Add contacts" : "Lägg till kontakter",
+    "Add users" : "Lägg till användare",
     "Add groups" : "Lägg till grupper",
     "Add emails" : "Lägg till e-post",
     "Add circles" : "Lägg till cirklar",
     "Searching …" : "Söker ...",
     "No results" : "Inga resultat",
-    "Search for more contacts" : "Sök efter fler kontakter",
-    "Add contacts, groups or circles" : "Lägg till kontakter, grupper och cirklar",
-    "Add contacts or groups" : "Lägg till kontakter eller grupper",
-    "Add contacts or circles" : "Lägg till kontakter eller cirklar",
+    "Search for more users" : "Sök efter fler användare",
+    "Add users, groups or circles" : "Lägg till användare, grupper eller cirklar",
+    "Add users or groups" : "Lägg till användare eller grupper",
+    "Add users or circles" : "Lägg till användare eller cirklar",
     "Add groups or circles" : "Lägg till grupper eller cirklar",
     "Add other sources" : "Lägg till andra källor",
     "Add participants to the conversation" : "Lägg till deltagare i konversationen",
@@ -330,6 +331,8 @@ OC.L10N.register(
     "Display name: " : "Visningsnamn:",
     "Edit" : "Ändra",
     "Start call" : "Starta samtal",
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal.",
+    "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
     "Dismiss" : "Avfärda",
     "Toggle fullscreen" : "Växla helskärm",
     "Go to file" : "Gå till fil",
@@ -352,10 +355,16 @@ OC.L10N.register(
     "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
     "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
     "Link to a conversation" : "Länka till en konversation",
+    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
+    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk uppdaterades, ladda om sidan igen",
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud är i underhållsläge, ladda om sidan igen",
     "Error while sharing file" : "Fel vid delning av fil",
     "Error while uploading file" : "Fel vid uppladdning av fil",
     "Sending signaling message has failed." : "Misslyckades skicka signalmeddelande.",
+    "Establishing signaling connection is taking longer than expected …" : "Det tar längre tid än förväntat att upprätta signalanslutning ...",
+    "Failed to establish signaling connection. Retrying …" : "Det gick inte att upprätta signalanslutning. Försöker igen ...",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du verkar prata med avstängd mikrofon, sätt på mikrofonen för att andra ska höra dig",
+    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Det gick inte att upprätta en anslutning med minst en deltagare. En TURN-server kan behövas för ditt scenario. Be din administratör att sätta upp en efter {linkstart}den här dokumentationen{linkend}.",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
     "Access to microphone & camera is only possible with HTTPS" : "Åtkomst till mikrofon och kamera är endast möjligt via HTTPS",
     "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
@@ -405,7 +414,6 @@ OC.L10N.register(
     "Error occurred while changing lobby state" : "Fel uppstod vid ändring av lobbyns status",
     "Invalid start time format" : "Ogiltigt format för starttid",
     "Error occurred while setting the lobby start time" : "Fel uppstod vid inställning av starttid för lobby",
-    "You" : "Du",
     "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
     "New message …" : "Nytt meddelande",
     "Send" : "Skicka",
@@ -430,6 +438,7 @@ OC.L10N.register(
     "Error while removing user from room" : "Kunde inte ta bort användaren från rummet",
     "Add participant …" : "Lägg till deltagare",
     "Favorited" : "Favorit",
+    "Your screen" : "Din skärm",
     "{participantName}'s screen" : "{participantName}'s skärm",
     "Guest's screen" : "Gästskärm",
     "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Konversationer kan nu ha en lobby. Detta gör att moderatorer nu kan förbereda mötet, medan användare och gäster måste vänta.",
@@ -441,8 +450,19 @@ OC.L10N.register(
     "Who can start a call?" : "Vem kan starta ett samtal?",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
     "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
+    "Contacts" : "Kontakter",
+    "Contacts, groups and circles" : "Kontakter, grupper och cirklar",
+    "Contacts and groups" : "Kontakter och grupper",
+    "Contacts and circles" : "Kontakter och cirklar",
     "Loading contacts" : "Laddar kontakter",
     "Select participants" : "Välj deltagare",
-    "Contacts loading" : "Laddar kontakter"
+    "Search conversations or contacts" : "Sök konversationer eller kontakter",
+    "Search for more contacts" : "Sök efter fler kontakter",
+    "Contacts loading" : "Laddar kontakter",
+    "Add contacts" : "Lägg till kontakter",
+    "Add contacts, groups or circles" : "Lägg till kontakter, grupper och cirklar",
+    "Add contacts or groups" : "Lägg till kontakter eller grupper",
+    "Add contacts or circles" : "Lägg till kontakter eller cirklar",
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal"
 },
 "nplurals=2; plural=(n != 1);");
