@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
@@ -22,7 +23,6 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Chat\Changelog;
 
-
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Manager as RoomManager;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -98,6 +98,10 @@ class Manager {
 			$this->l->t('- You can now directly reply to messages giving the other users more context what your message is about'),
 			$this->l->t('- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations'),
 			$this->l->t('- You can now add custom user groups to conversations when the circles app is installed'),
+			$this->l->t('New in Talk 9'),
+			$this->l->t('- Check out the new grid and call view'),
+			$this->l->t('- You can now upload and drag\'n\'drop files directly from your device into the chat'),
+			$this->l->t('- Shared files are now opened directly inside the chat view with the viewer apps'),
 		];
 	}
 }
