@@ -1015,6 +1015,38 @@ class Room {
 		return $participants;
 	}
 
+	/**
+	 * @param string $search
+	 * @param int $limit
+	 * @param int $offset
+	 * @return Participant[]
+	 */
+	public function searchParticipants(string $search = '', int $limit = null, int $offset = null): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('*')
+			->from('talk_participants')
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId())));
+
+		if ($search !== '') {
+			$query->where($query->expr()->iLike('user_id', $query->createNamedParameter(
+				'%' . $this->db->escapeLikeParameter($search) . '%'
+			)));
+		}
+
+		$query->setMaxResults($limit)
+			->setFirstResult($offset)
+			->orderBy('user_id', 'ASC');
+		$result = $query->execute();
+
+		$participants = [];
+		while ($row = $result->fetch()) {
+			$participants[] = $this->manager->createParticipantObject($this, $row);
+		}
+		$result->closeCursor();
+
+		return $participants;
+	}
+
 	/**
 	 * @return Participant[]
 	 */
@@ -1287,8 +1319,7 @@ class Room {
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_participants')
 			->set('last_ping', $query->createNamedParameter($timestamp, IQueryBuilder::PARAM_INT))
-			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->in('session_id', $query->createNamedParameter($sessionIds, IQueryBuilder::PARAM_STR_ARRAY)));
+			->where($query->expr()->in('session_id', $query->createNamedParameter($sessionIds, IQueryBuilder::PARAM_STR_ARRAY)));
 
 		$query->execute();
 	}
